@@ -15,7 +15,7 @@ class ftpUtil:
     __password_stud ="student"
     __remotedir_media = "/media/"
     __remotedir_stud = "/send/"
-    __url_head="http://home.hddly.cn:90/stud/"
+    __url_head="http://i.hddly.cn/stud/"
     __mutil= mysqlUtil()
 
     def chk_file_exist_surl(self,surl,fdesc):
