@@ -2,9 +2,9 @@ import json
 import sys
 
 import pandas as pd
+from bgutils.redisUtil import redisUtil
 from sqlalchemy import create_engine
 from sqlalchemy import text
-from redisUtil import redisUtil
 
 class mysqlUtil:
     __mysql_username = 'test'
@@ -118,8 +118,15 @@ class mysqlUtil:
             # print(df)
             surl=surl[0:99] #截取字符串前100个字符
             row1 = pd.DataFrame(
-                {'filename': filename, 'url': url, 'stud': stud, 'fdesc': fdesc, 'fsize': fsize, 'duration': duration,
-                 'ftype': ftype,'pid':pid,'surl':surl}, index=[1])
+                {'filename': self.escape(filename),
+                 'url': self.escape(url),
+                 'stud': self.escape(stud),
+                 'fdesc': self.escape(fdesc),
+                 'fsize': fsize,
+                 'duration': duration,
+                 'ftype': ftype,
+                 'pid':pid,
+                 'surl':self.escape(surl)}, index=[1])
             # print(row1)
             # df=df.append(row1,ignore_index=True)
             df = pd.concat([df, row1], ignore_index=True)  # append过时，改用concat
@@ -173,3 +180,13 @@ class mysqlUtil:
         data = pd.DataFrame(dict(item), index=[0])
         data.to_sql(tblname, self.engine, if_exists='append', index=False)  # 'taobao_data'
         return item
+
+    def escape(self,content) :
+        if (content and len(str(content).strip()))>0 :
+            content = content.replace("\\\\", "\\\\\\\\");
+            content = content.replace("_", "\\\\_");
+            content = content.replace("%", "\\\\%");
+            content = content.replace("'", "\\\\'");
+
+        return content;
+
