@@ -28,6 +28,16 @@ class redisUtil:
         re_pool = redis.Redis(connection_pool=self.conn_pool)
         return re_pool.srem(setname,setvalue)
 
+    #将集合中的所有元素删除
+    def sremoveall(self,setname):
+        re_pool = redis.Redis(connection_pool=self.conn_pool)
+        value=re_pool.spop(setname)
+        i=0
+        while (value):
+            value = re_pool.spop(setname)
+            i=i+1
+        return i
+
     #获取集合元素个数
     def scard(self,setname):
         re_pool = redis.Redis(connection_pool=self.conn_pool)
